package cn.dankal.test.common.service.advice;

import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import javax.servlet.http.HttpServletResponse;

/**
 * {@link RestControllerAdvice,Slf4j}
 * 服务全局异常处理
 *
 * @author ZGH.MercyModest
 * @version V1.0.0
 * @create 2020/10/19
 */
@Slf4j
@RestControllerAdvice(basePackages = {"cn.dankal.test"})
public class GlobalExceptionAdvice {

    /**
     * 处理 全局 Exception 异常
     *
     * @param exception Exception Object
     * @return 异常信息:[exception.getCause().getMessage(),exception.getMessage()]
     */
    @ExceptionHandler({Exception.class})
    public String handlerException(Exception exception, HttpServletResponse response) {
        Throwable exceptionCause = exception.getCause();
        String exceptionInfo = (exceptionCause == null ? "发生异常" : exceptionCause.getMessage()) + " --> " + exception.getMessage();
        log.error("throws a exception : {}", exceptionInfo);
        response.setContentType("application/json; charset=UTF-8");
        return exceptionInfo;
    }
}
